from manim import *



class ArgMinExample(Scene):

    def construct(self):

        number_plane = NumberPlane(
            background_line_style={
                "stroke_color": TEAL,
                "stroke_width": 1,
                "stroke_opacity": 0.2
            }
        )
        self.add(number_plane)


        ax = Axes(
            x_range=[15, 35], y_range=[5, 25, 200], axis_config={"include_tip": False}
        )
        labels = ax.get_axis_labels(x_label="V", y_label="p")

        t = ValueTracker(0)

        def func_1(x):
            return 1300/x**(7/5)
        def func_5(x):
            return 900/x**(7/5)

        tdc = 18
        ldc = 31

        graph1 = ax.plot(func_1, x_range=[tdc,ldc], color=MAROON)
        graph2 = Line(ax.coords_to_point(ldc, func_1(ldc), 0),
                      ax.coords_to_point(ldc, func_5(ldc), 0)).set_color(MAROON)
        graph3 = Line(ax.coords_to_point(ldc, func_5(ldc), 0),
                      ax.coords_to_point(tdc, func_5(ldc), 0)).set_color(MAROON)
        graph4 = Line(ax.coords_to_point(tdc, func_5(ldc), 0),
                      ax.coords_to_point(ldc, func_5(ldc), 0)).set_color(MAROON)
        graph5 = ax.plot(func_5, x_range=[ldc, tdc, -0.1], color=MAROON)
        graph6 = Line(ax.coords_to_point(tdc, func_5(tdc), 0),
                      ax.coords_to_point(tdc, func_1(tdc), 0)).set_color(MAROON)

        text1 = Text( "Adiabatic Expansion", font_size=25 ).move_to([1.2, 0.5,0])
        text2 = Text( "Isochoric\n Cooling", font_size=25 ).move_to([4.4, -1.8,0])
        text3 = Text( "Isobaric Compression", font_size=25 ).move_to([-0.2, -2.2,0])
        text4 = Text( "Isobaric Expansion", font_size=25 ).move_to([-0.2, -2.6,0])
        text5 = Text( "Adiabatic Compression", font_size=25 ).move_to([-1.0, -1.5,0])
        text6 = Text( "Isochoric \n Heating", font_size=25 ).move_to([-5.5, 1.2,0])

        self.add(ax, labels)
        self.wait()

        self.play(Create(graph1), Create(text1) )
        self.play(Create(graph2), Create(text2) )
        self.play(Create(graph3), Create(text3) )
        self.play(Create(graph4), Create(text4) )
        self.play(Create(graph5), Create(text5) )
        self.play(Create(graph6), Create(text6) )
        self.wait(0.5)
        ##graph1 = graph1.copy().set_color(RED),

        timew = 0.3
        timer = 1.1
        for i in range(3):
            self.play( ShowPassingFlash(
                graph1.copy().set_color(BLUE),
                run_time=timer,
                time_width=timew
            ) )
            self.play( ShowPassingFlash(
                graph2.copy().set_color(BLUE),
                run_time=timer,
                time_width=timew
            ) )
            self.play( ShowPassingFlash(
                graph3.copy().set_color(BLUE),
                run_time=timer,
                time_width=timew
            ) )

            self.play( ShowPassingFlash(
                graph4.copy().set_color(BLUE),
                run_time=timer,
                time_width=timew
            ) )

            self.play( ShowPassingFlash(
                graph5.copy().set_color(BLUE),
                run_time=timer,
                time_width=timew
            ) )

            self.play( ShowPassingFlash(
                graph6.copy().set_color(BLUE),
                run_time=timer,
                time_width=timew
            ) )



